@@ -207,8 +207,11 @@ class SQLCli(object):
                             connect_parameters[2] + '://' + connect_parameters[3] + ':' + \
                             connect_parameters[4] + ':/' + connect_parameters[5]
                     else:
-                        print(str(connect_parameters))
-                        print(len(connect_parameters))
+                        print("db_type = [" + str(self.db_type) + "]")
+                        print("db_host = [" + str(self.db_host) + "]")
+                        print("db_port = [" + str(self.db_port) + "]")
+                        print("db_service_name = [" + str(self.db_service_name) + "]")
+                        print("db_url = [" + str(self.db_url) + "]")
                         raise SQLCliException("Unexpeced env SQLCLI_CONNECTION_URL\n." +
                                               "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
                 else:
@@ -218,15 +221,34 @@ class SQLCli(object):
 
         # 连接数据库
         try:
-            self.db_conn = jaydebeapi.connect(self.driver_class,
-                                              'jdbc:' + self.db_type + ":" + self.db_driver_type + "://" +
-                                              self.db_host + ":" + self.db_port + "/" + self.db_service_name,
-                                              [self.db_username, self.db_password],
-                                              self.jar_file, )
+            if (self.db_type.upper() == "ORACLE"):
+                self.db_conn = jaydebeapi.connect(self.driver_class,
+                                                  'jdbc:' + self.db_type + ":" + self.db_driver_type + ":@" +
+                                                  self.db_host + ":" + self.db_port + "/" + self.db_service_name,
+                                                  [self.db_username, self.db_password],
+                                                  self.jar_file, )
+            elif (self.db_type.upper() == "LINKOOPDB"):
+                self.db_conn = jaydebeapi.connect(self.driver_class,
+                                                  'jdbc:' + self.db_type + ":" + self.db_driver_type + "://" +
+                                                  self.db_host + ":" + self.db_port + "/" + self.db_service_name +
+                                                  ";query_iterator=1",
+                                                  [self.db_username, self.db_password],
+                                                  self.jar_file, )
+            else:
+                self.db_conn = jaydebeapi.connect(self.driver_class,
+                                                  'jdbc:' + self.db_type + ":" + self.db_driver_type + "://" +
+                                                  self.db_host + ":" + self.db_port + "/" + self.db_service_name,
+                                                  [self.db_username, self.db_password],
+                                                  self.jar_file, )
             self.sqlexecute.set_connection(self.db_conn)
         except Exception as e:  # Connecting to a database fail.
             print('traceback.print_exc():\n%s' % traceback.print_exc())
             print('traceback.format_exc():\n%s' % traceback.format_exc())
+            print("db_type = [" + str(self.db_type) + "]")
+            print("db_host = [" + str(self.db_host) + "]")
+            print("db_port = [" + str(self.db_port) + "]")
+            print("db_service_name = [" + str(self.db_service_name) + "]")
+            print("db_url = [" + str(self.db_url) + "]")
             raise SQLCliException(repr(e))
 
         yield (
