@@ -20,7 +20,7 @@ class SQLExecute(object):
     def __init__(self):
         # 设置一些默认的参数
         self.options = {"WHENEVER_SQLERROR": "CONTINUE", "PAGE": "OFF", "OUTPUT_FORMAT": "ASCII", "ECHO": "OFF",
-                        "LONG": 20, 'KAFKA_SERVERS': None, 'TIMING': 'OFF'}
+                        "LONG": 20, 'KAFKA_SERVERS': None, 'TIMING': 'OFF', 'TERMOUT': 'ON', 'FEEDBACK': 'ON'}
 
     def set_connection(self, p_conn):
         self.conn = p_conn
@@ -44,8 +44,8 @@ class SQLExecute(object):
             m_CommentSQL = ret_SQLSplitResultsWithComments[m_nPos]
 
             # SQL的回显
-            if self.options["ECHO"] == 'ON' and len(m_CommentSQL.strip()) != 0 and  self.logfile is not None:
-                click.echo(SQLFormatWithPrefix(m_CommentSQL), file = self.logfile)
+            if self.options["ECHO"] == 'ON' and len(m_CommentSQL.strip()) != 0 and self.logfile is not None:
+                click.echo(SQLFormatWithPrefix(m_CommentSQL), file=self.logfile)
 
             # 如果运行在脚本模式下，需要在控制台回显SQL
             if self.sqlscript is not None:
@@ -78,6 +78,10 @@ class SQLExecute(object):
                     raise SQLCliException("Not Connected. ")
             cur = self.conn.cursor() if self.conn else None
 
+            # 记录命令开始时间
+            start = time.time()
+
+            # 执行SQL
             try:
                 # 首先假设这是一个特殊命令
                 for result in execute(cur, sql):
@@ -86,15 +90,8 @@ class SQLExecute(object):
                 # 执行正常的SQL语句
                 if cur is not None:
                     try:
-                        start = time.clock()
                         cur.execute(sql)
                         yield self.get_result(cur)
-                        end = time.clock()
-
-                        # 如果需要，打印语句执行时间
-                        if self.options['TIMING'] == 'ON':
-                            yield None, None, None, 'Running time: %10.2f Seconds' % (end - start)
-
                     except Exception as e:
                         if (
                                 str(e).find("SQLSyntaxErrorException") != -1 or
@@ -113,33 +110,64 @@ class SQLExecute(object):
                 else:
                     raise e
 
+            # 记录结束时间
+            end = time.time()
+            # 如果需要，打印语句执行时间
+            if self.options['TIMING'] == 'ON':
+                if sql.strip().upper() not in ('EXIT','QUIT'):
+                    yield None, None, None, 'Running time elapsed: %8.2f Seconds' % (end - start)
+
     def get_result(self, cursor):
         """Get the current result's data from the cursor."""
         title = headers = None
 
         # cursor.description is not None for queries that return result sets,
         # e.g. SELECT.
+        result = []
         if cursor.description is not None:
             headers = [x[0] for x in cursor.description]
             status = "{0} row{1} selected."
-            cursor = list(cursor.fetchall())
-            result = []
-            for row in cursor:
-                m_row = []
-                for column in row:
-                    if str(type(column)).find('JDBCClobClient') != -1:
-                        m_row.append(column.getSubString(1, int(self.options["LONG"])))
-                    else:
-                        m_row.append(column)
-                m_row = tuple(m_row)
-                result.append(m_row)
-            cursor = result
-            rowcount = len(cursor)
+
+            #rowset = list(cursor.fetchall())
+            #for row in rowset:
+            #    m_row = []
+            #    for column in row:
+            #        if str(type(column)).find('JDBCClobClient') != -1:
+            #            m_row.append(column.getSubString(1, int(self.options["LONG"])))
+            #        else:
+            #            m_row.append(column)
+            #    m_row = tuple(m_row)
+            #    result.append(m_row)
+
+            rowcount = 0
+            while True:
+                m_arraysize = 10
+                rowset = list(cursor.fetchmany(m_arraysize))
+                if self.options['TERMOUT']  != 'OFF':
+                    for row in rowset:
+                        m_row = []
+                        for column in row:
+                            if str(type(column)).find('JDBCClobClient') != -1:
+                                m_row.append(column.getSubString(1, int(self.options["LONG"])))
+                            else:
+                                m_row.append(column)
+                        m_row = tuple(m_row)
+                        result.append(m_row)
+                rowcount = rowcount + len(rowset)
+                if len(rowset) < m_arraysize:
+                    # 已经没有什么可以取的了, 游标结束
+                    break
         else:
             _logger.debug("No rows in result.")
             status = "{0} row{1} affected"
             rowcount = 0 if cursor.rowcount == -1 else cursor.rowcount
-            cursor = None
+            result = None
 
-        status = status.format(rowcount, "" if rowcount == 1 else "s")
-        return title, cursor, headers, status
+        if self.options['FEEDBACK'] == 'ON':
+            status = status.format(rowcount, "" if rowcount == 1 else "s")
+        else:
+            status  = None
+        if self.options['TERMOUT'] == 'OFF':
+            return title, [], headers, status
+        else:
+            return title, result, headers, status
